DestructionWatcherRequest

Enum DestructionWatcherRequest 

pub enum DestructionWatcherRequest {
    Watch {
        responder: DestructionWatcherWatchResponder,
    },
#[non_exhaustive]
_UnknownMethod { ordinal: u64, control_handle: DestructionWatcherControlHandle, method_type: MethodType, }, }
Protocol for watching socket destruction events.

Variants



Watch

Hanging get for destroyed sockets.

Returns sockets destroyed since the last call to this method. Blocks until at least one event is available.

A “destroyed” socket is one that no longer has any references inside the Netstack. Especially for TCP sockets (because of TIME-WAIT), this may happen long after close has returned.

Sockets destroyed before the watcher was created are not returned. Unbound sockets are not returned.

Only one call to Watch may be active at a time. Concurrency is not allowed and will result in the channel being closed with ALREADY_EXISTS.

If the client doesn’t read events fast enough, the channel is closed with NO_RESOURCES.



#[non_exhaustive]
_UnknownMethod

An interaction was received which does not match any known method.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
ordinal: u64

Ordinal of the method that was called.

method_type: MethodType

Implementations

Source

impl DestructionWatcherRequest

pub fn into_watch(self) -> Option<DestructionWatcherWatchResponder>

pub fn method_name(&self) -> &'static str

Name of the method defined in FIDL