pub struct DestructionWatcherMarker;Trait Implementations
Sourceimpl Clone for DestructionWatcherMarker
impl Clone for DestructionWatcherMarker
Sourcefn clone(&self) -> DestructionWatcherMarker
fn clone(&self) -> DestructionWatcherMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DestructionWatcherMarker
impl Debug for DestructionWatcherMarker
Sourceimpl Hash for DestructionWatcherMarker
impl Hash for DestructionWatcherMarker
Sourceimpl Ord for DestructionWatcherMarker
impl Ord for DestructionWatcherMarker
Sourcefn cmp(&self, other: &DestructionWatcherMarker) -> Ordering
fn cmp(&self, other: &DestructionWatcherMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DestructionWatcherMarker
impl PartialEq for DestructionWatcherMarker
Sourcefn eq(&self, other: &DestructionWatcherMarker) -> bool
fn eq(&self, other: &DestructionWatcherMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DestructionWatcherMarker
impl PartialOrd for DestructionWatcherMarker
Sourceimpl ProtocolMarker for DestructionWatcherMarker
impl ProtocolMarker for DestructionWatcherMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) DestructionWatcher"
const DEBUG_NAME: &'static str = "(anonymous) DestructionWatcher"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = DestructionWatcherProxy
type Proxy = DestructionWatcherProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = DestructionWatcherRequestStream
type RequestStream = DestructionWatcherRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = DestructionWatcherSynchronousProxy
type SynchronousProxy = DestructionWatcherSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for DestructionWatcherMarker
impl Eq for DestructionWatcherMarker
impl StructuralPartialEq for DestructionWatcherMarker