pub struct DestructionWatcherProxy { /* private fields */ }Implementations
Sourceimpl DestructionWatcherProxy
impl DestructionWatcherProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.net.sockets/DestructionWatcher.
Sourcepub fn take_event_stream(&self) -> DestructionWatcherEventStream
pub fn take_event_stream(&self) -> DestructionWatcherEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn watch(
&self,
) -> QueryResponseFut<Vec<IpSocketState>, DefaultFuchsiaResourceDialect>
pub fn watch( &self, ) -> QueryResponseFut<Vec<IpSocketState>, DefaultFuchsiaResourceDialect>
Hanging get for destroyed sockets.
Returns sockets destroyed since the last call to this method. Blocks until at least one event is available.
A “destroyed” socket is one that no longer has any references inside the
Netstack. Especially for TCP sockets (because of TIME-WAIT), this may
happen long after close has returned.
Sockets destroyed before the watcher was created are not returned. Unbound sockets are not returned.
Only one call to Watch may be active at a time. Concurrency is not
allowed and will result in the channel being closed with
ALREADY_EXISTS.
If the client doesn’t read events fast enough, the channel is closed
with NO_RESOURCES.