pub struct DestructionWatcherWatchResponder { /* private fields */ }Implementations
Sourceimpl DestructionWatcherWatchResponder
impl DestructionWatcherWatchResponder
Sourcepub fn send(self, sockets: &[IpSocketState]) -> Result<(), Error>
pub fn send(self, sockets: &[IpSocketState]) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
sockets: &[IpSocketState],
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, sockets: &[IpSocketState], ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.