pub struct DiagnosticsGetDestructionWatcherRequest {
pub watcher: ServerEnd<DestructionWatcherMarker>,
}Fields
watcher: ServerEnd<DestructionWatcherMarker>Trait Implementations
Sourceimpl Decode<DiagnosticsGetDestructionWatcherRequest, DefaultFuchsiaResourceDialect> for DiagnosticsGetDestructionWatcherRequest
impl Decode<DiagnosticsGetDestructionWatcherRequest, DefaultFuchsiaResourceDialect> for DiagnosticsGetDestructionWatcherRequest
Sourceimpl Encode<DiagnosticsGetDestructionWatcherRequest, DefaultFuchsiaResourceDialect> for &mut DiagnosticsGetDestructionWatcherRequest
impl Encode<DiagnosticsGetDestructionWatcherRequest, DefaultFuchsiaResourceDialect> for &mut DiagnosticsGetDestructionWatcherRequest
Sourceimpl<T0: Encode<Endpoint<ServerEnd<DestructionWatcherMarker>>, DefaultFuchsiaResourceDialect>> Encode<DiagnosticsGetDestructionWatcherRequest, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<Endpoint<ServerEnd<DestructionWatcherMarker>>, DefaultFuchsiaResourceDialect>> Encode<DiagnosticsGetDestructionWatcherRequest, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl Ord for DiagnosticsGetDestructionWatcherRequest
impl Ord for DiagnosticsGetDestructionWatcherRequest
Sourcefn cmp(&self, other: &DiagnosticsGetDestructionWatcherRequest) -> Ordering
fn cmp(&self, other: &DiagnosticsGetDestructionWatcherRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DiagnosticsGetDestructionWatcherRequest
impl PartialEq for DiagnosticsGetDestructionWatcherRequest
Sourcefn eq(&self, other: &DiagnosticsGetDestructionWatcherRequest) -> bool
fn eq(&self, other: &DiagnosticsGetDestructionWatcherRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DiagnosticsGetDestructionWatcherRequest
impl PartialOrd for DiagnosticsGetDestructionWatcherRequest
Sourceimpl ResourceTypeMarker for DiagnosticsGetDestructionWatcherRequest
impl ResourceTypeMarker for DiagnosticsGetDestructionWatcherRequest
Sourcetype Borrowed<'a> = &'a mut DiagnosticsGetDestructionWatcherRequest
type Borrowed<'a> = &'a mut DiagnosticsGetDestructionWatcherRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for DiagnosticsGetDestructionWatcherRequest
impl TypeMarker for DiagnosticsGetDestructionWatcherRequest
Sourcetype Owned = DiagnosticsGetDestructionWatcherRequest
type Owned = DiagnosticsGetDestructionWatcherRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Eq for DiagnosticsGetDestructionWatcherRequest
impl Standalone<DefaultFuchsiaResourceDialect> for DiagnosticsGetDestructionWatcherRequest
impl StructuralPartialEq for DiagnosticsGetDestructionWatcherRequest