pub struct Extensions(/* private fields */);Implementations
Sourceimpl Extensions
impl Extensions
Sourcepub const TCP_INFO: Extensions
pub const TCP_INFO: Extensions
Populates the tcp_info field on returned TCP sockets.
Sourceimpl Extensions
impl Extensions
Sourcepub const fn empty() -> Extensions
pub const fn empty() -> Extensions
Get a flags value with all bits unset.
Sourcepub const fn all() -> Extensions
pub const fn all() -> Extensions
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Extensions>
pub const fn from_bits(bits: u32) -> Option<Extensions>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Extensions
pub const fn from_bits_truncate(bits: u32) -> Extensions
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Extensions
pub const fn from_bits_retain(bits: u32) -> Extensions
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Extensions>
pub fn from_name(name: &str) -> Option<Extensions>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Extensions) -> bool
pub const fn intersects(&self, other: Extensions) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Extensions) -> bool
pub const fn contains(&self, other: Extensions) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: Extensions)
pub fn insert(&mut self, other: Extensions)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: Extensions)
pub fn remove(&mut self, other: Extensions)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Extensions)
pub fn toggle(&mut self, other: Extensions)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Extensions, value: bool)
pub fn set(&mut self, other: Extensions, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Extensions) -> Extensions
pub const fn intersection(self, other: Extensions) -> Extensions
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Extensions) -> Extensions
pub const fn union(self, other: Extensions) -> Extensions
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Extensions) -> Extensions
pub const fn difference(self, other: Extensions) -> Extensions
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Extensions) -> Extensions
pub const fn symmetric_difference(self, other: Extensions) -> Extensions
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Extensions
pub const fn complement(self) -> Extensions
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Extensions
impl Extensions
Sourcepub const fn iter(&self) -> Iter<Extensions> ⓘ
pub const fn iter(&self) -> Iter<Extensions> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Extensions> ⓘ
pub const fn iter_names(&self) -> IterNames<Extensions> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Extensions
impl Extensions
pub fn from_bits_allow_unknown(bits: u32) -> Extensions
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u32