pub struct DestructionWatcherSynchronousProxy { /* private fields */ }Implementations
Sourceimpl DestructionWatcherSynchronousProxy
impl DestructionWatcherSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<DestructionWatcherEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<DestructionWatcherEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn watch(
&self,
___deadline: MonotonicInstant,
) -> Result<Vec<IpSocketState>, Error>
pub fn watch( &self, ___deadline: MonotonicInstant, ) -> Result<Vec<IpSocketState>, Error>
Hanging get for destroyed sockets.
Returns sockets destroyed since the last call to this method. Blocks until at least one event is available.
A “destroyed” socket is one that no longer has any references inside the
Netstack. Especially for TCP sockets (because of TIME-WAIT), this may
happen long after close has returned.
Sockets destroyed before the watcher was created are not returned. Unbound sockets are not returned.
Only one call to Watch may be active at a time. Concurrency is not
allowed and will result in the channel being closed with
ALREADY_EXISTS.
If the client doesn’t read events fast enough, the channel is closed
with NO_RESOURCES.